==> components-1.1.0.tgz: package/es/DropDown/props/propTypes.js <==
import PropTypes from 'prop-types';
export const DropDown_propTypes = {
  arrowBottom: PropTypes.string,
  arrowLeft: PropTypes.string,
  arrowPosition: PropTypes.string,
  arrowRight: PropTypes.string,
  arrowTop: PropTypes.string,
  bottom: PropTypes.string,
  boxPosition: PropTypes.string,
  children: PropTypes.node,
  isAnimate: PropTypes.bool,
  isArrow: PropTypes.bool,
  isPopupOpen: PropTypes.bool,
  left: PropTypes.string,
  onClick: PropTypes.func,
  right: PropTypes.string,
  size: PropTypes.string,
  top: PropTypes.string
};
export const DropDownTarget_propTypes = {
  children: PropTypes.node
};
export const DropDownContainer_propTypes = {
  children: PropTypes.node
};
export const DropDownItemContainer_propTypes = {
  children: PropTypes.node,
  dataId: PropTypes.string,
  getRef: PropTypes.func,
  onScroll: PropTypes.func
};
export const DropDownHeading_propTypes = {
  children: PropTypes.node,
  customClass: PropTypes.string,
  palette: PropTypes.oneOf(['light', 'dark']),
  text: PropTypes.string,
  title: PropTypes.string,
  htmlId: PropTypes.string,
  a11y: PropTypes.shape({
    role: PropTypes.string,
    ariaLabelledby: PropTypes.string,
    ariaLabel: PropTypes.string
  })
};
export const DropDownItem_propTypes = {
  active: PropTypes.bool,
  children: PropTypes.node,
  dataId: PropTypes.string,
  getRef: PropTypes.func,
  hightlight: PropTypes.bool,
  id: PropTypes.string,
  index: PropTypes.number,
  onClick: PropTypes.func,
  onHover: PropTypes.func,
  value: PropTypes.string,
  customClass: PropTypes.string
};
export const DropDownSearch_propTypes = {
  getRef: PropTypes.func,
  id: PropTypes.string,
  maxLength: PropTypes.string,
  name: PropTypes.string,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  onKeyDown: PropTypes.func,
  placeHolder: PropTypes.string,
  placeHolder: PropTypes.string,
  size: PropTypes.oneOf(['small', 'medium']),
  textBoxSize: PropTypes.string,
  value: PropTypes.string,
  customClass: PropTypes.shape({
    searchClass: PropTypes.string,
    customTextBox: PropTypes.string
  })
};
export const DropDownSeparator_propTypes = {
  customClass: PropTypes.string
};

==> components-1.2.14.tgz: package/es/DropDown/props/propTypes.js <==
import PropTypes from 'prop-types';
import { PopOver_propTypes } from './../../PopOver/props/propTypes';
export const DropDown_propTypes = { ...PopOver_propTypes
};
export const DropDownTarget_propTypes = {
  children: PropTypes.node
};
export const DropDownContainer_propTypes = {
  children: PropTypes.node
};
export const DropDownItemContainer_propTypes = {
  children: PropTypes.node,
  dataId: PropTypes.string,
  getRef: PropTypes.func,
  onScroll: PropTypes.func
};
export const DropDownHeading_propTypes = {
  children: PropTypes.node,
  customClass: PropTypes.string,
  palette: PropTypes.oneOf(['light', 'dark']),
  text: PropTypes.string,
  title: PropTypes.string,
  htmlId: PropTypes.string,
  a11y: PropTypes.shape({
    role: PropTypes.string,
    ariaLabelledby: PropTypes.string,
    ariaLabel: PropTypes.string
  }),
  dataId: PropTypes.string,
  dataSelectorId: PropTypes.string
};
export const DropDownItem_propTypes = {
  active: PropTypes.bool,
  children: PropTypes.node,
  dataId: PropTypes.string,
  getRef: PropTypes.func,
  hightlight: PropTypes.bool,
  id: PropTypes.string,
  index: PropTypes.number,
  onClick: PropTypes.func,
  onHover: PropTypes.func,
  value: PropTypes.string,
  customClass: PropTypes.string
};
export const DropDownSearch_propTypes = {
  getRef: PropTypes.func,
  id: PropTypes.string,
  maxLength: PropTypes.string,
  name: PropTypes.string,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  onKeyDown: PropTypes.func,
  placeHolder: PropTypes.string,
  placeHolder: PropTypes.string,
  size: PropTypes.oneOf(['small', 'medium']),
  textBoxSize: PropTypes.string,
  value: PropTypes.string,
  customClass: PropTypes.shape({
    searchClass: PropTypes.string,
    customTextBox: PropTypes.string
  })
};
export const DropDownSeparator_propTypes = {
  customClass: PropTypes.string
};
